==> qtjambi-datavisualization-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiDataVisualization/QAbstractDataProxy_shell.cpp <==
#include "QAbstractDataProxy_shell.h"

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtJambi/Cast>

QtJambiShell* QAbstractDataProxy_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractDataProxy_shell) ); }

jmethodID QAbstractDataProxy_shell::__shell_javaMethod(int pos) const { return QAbstractDataProxy_shell::__shell()->javaMethod(typeid(QtDataVisualization::QAbstractDataProxy), pos); }

// emitting (writeShellConstructor)
// emitting (writeShellDestructor)
QAbstractDataProxy_shell::~QAbstractDataProxy_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QtDataVisualization::QAbstractDataProxy::~QtDataVisualization::QAbstractDataProxy()", QAbstractDataProxy_shell::__shell())
    QAbstractDataProxy_shell::__shell()->destructed(typeid(QtDataVisualization::QAbstractDataProxy));
}

void QAbstractDataProxy_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractDataProxy_shell*>(ptr)->QAbstractDataProxy_shell::__shell()->tryDeleteShell(typeid(QtDataVisualization::QAbstractDataProxy));
}

// emitting (writeQObjectFunctions)
const QMetaObject *QAbstractDataProxy_shell::metaObject() const
{
  return QAbstractDataProxy_shell::__shell()->metaObject();
}

void *QAbstractDataProxy_shell::qt_metacast(const char *_clname)
{
    bool ok = false;
    void *rv = QAbstractDataProxy_shell::__shell()->qt_metacast(_clname, &ok);
    QTJAMBI_INTERNAL_INSTANCE_METHOD_CALL("QAbstractDataProxy_shell::qt_metacast(const char *_clname)", QAbstractDataProxy_shell::__shell())
    if (!ok)
        rv = QtDataVisualization::QAbstractDataProxy::qt_metacast(_clname);
    return rv;
}

int QAbstractDataProxy_shell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    QTJAMBI_INTERNAL_INSTANCE_METHOD_CALL("QAbstractDataProxy_shell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)", QAbstractDataProxy_shell::__shell())
    _id = QtDataVisualization::QAbstractDataProxy::qt_metacall(_c, _id, _a);
    if (_id >= 0)
        _id = QAbstractDataProxy_shell::__shell()->qt_metacall(_c, _id, _a);
    return _id;
}

// emitting Virtual overrides (virtualFunctions)
void QAbstractDataProxy_shell::childEvent(QChildEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QtDataVisualization::QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QtDataVisualization::QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QtDataVisualization::QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::childEvent(event0);
        }
    }else{
        QObject::childEvent(event0);
    }
}

void QAbstractDataProxy_shell::connectNotify(const QMetaMethod& signal0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QtDataVisualization::QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_signal0 = qtjambi_cast<jobject>(__jni_env, signal0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_signal0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QtDataVisualization::QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QtDataVisualization::QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::connectNotify(signal0);
        }
    }else{
        QObject::connectNotify(signal0);
    }
}

void QAbstractDataProxy_shell::customEvent(QEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("QtDataVisualization::QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QtDataVisualization::QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QtDataVisualization::QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::customEvent(event0);
        }
    }else{
        QObject::customEvent(event0);
    }
}

void QAbstractDataProxy_shell::disconnectNotify(const QMetaMethod& signal0)
{
    if(jmethodID method_id = __shell_javaMethod(3)){
        QTJAMBI_JAVA_METHOD_CALL("QtDataVisualization::QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_signal0 = qtjambi_cast<jobject>(__jni_env, signal0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_signal0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QtDataVisualization::QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QtDataVisualization::QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::disconnectNotify(signal0);
        }
    }else{
        QObject::disconnectNotify(signal0);
    }
}

bool QAbstractDataProxy_shell::event(QEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(4)){
        QTJAMBI_JAVA_METHOD_CALL("QtDataVisualization::QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    if(event0->type()==QEvent::DeferredDelete || event0->type()==QEvent::ChildRemoved){
                        __qt_return_value = QObject::event(event0);
                    } else {
                        QAbstractDataProxy_shell::__shell()->warnForMethod("QtDataVisualization::QAbstractDataProxy::", this);
                    }
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QtDataVisualization::QAbstractDataProxy::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QObject::event(event0);
        }
    }else{
        return QObject::event(event0);
    }
}

bool QAbstractDataProxy_shell::eventFilter(QObject* watched0, QEvent* event1)
{
    if(jmethodID method_id = __shell_javaMethod(5)){
        QTJAMBI_JAVA_METHOD_CALL("QtDataVisualization::QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_watched0 = qtjambi_cast<jobject>(__jni_env, watched0);
                    jobject __java_event1 = qtjambi_cast<jobject>(__jni_env, event1);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event1);
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_watched0, __java_event1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    if(event1->type()==QEvent::DeferredDelete || event1->type()==QEvent::ChildRemoved){
                        __qt_return_value = QObject::eventFilter(watched0, event1);
                    } else {
                        QAbstractDataProxy_shell::__shell()->warnForMethod("QtDataVisualization::QAbstractDataProxy::", this);
                    }
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QtDataVisualization::QAbstractDataProxy::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QObject::eventFilter(watched0, event1);
        }
    }else{
        return QObject::eventFilter(watched0, event1);
    }
}

void QAbstractDataProxy_shell::timerEvent(QTimerEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(6)){
        QTJAMBI_JAVA_METHOD_CALL("QtDataVisualization::QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QtDataVisualization::QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QtDataVisualization::QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::timerEvent(event0);
        }
    }else{
        QObject::timerEvent(event0);
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// destruct QAbstractDataProxy_shell
void __qt_destruct_QtDataVisualization_QAbstractDataProxy(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QtDataVisualization::QAbstractDataProxy")
    reinterpret_cast<QAbstractDataProxy_shell*>(ptr)->~QAbstractDataProxy_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QtDataVisualization::QAbstractDataProxy::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_datavis_QAbstractDataProxy_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QtDataVisualization::QAbstractDataProxy *__qt_this = QtJambiAPI::objectFromNativeId<QtDataVisualization::QAbstractDataProxy>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QtDataVisualization::QAbstractDataProxy::type()const", __qt_this)
        QtDataVisualization::QAbstractDataProxy::DataType __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QtDataVisualization_QAbstractDataProxy(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QtDataVisualization::QAbstractDataProxy>("QtDataVisualization::QAbstractDataProxy", "io/qt/datavis/QAbstractDataProxy");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "childEvent", "(Lio/qt/core/QChildEvent;)V"),
        FunctionInfo(/* 1 */ "connectNotify", "(Lio/qt/core/QMetaMethod;)V"),
        FunctionInfo(/* 2 */ "customEvent", "(Lio/qt/core/QEvent;)V"),
        FunctionInfo(/* 3 */ "disconnectNotify", "(Lio/qt/core/QMetaMethod;)V"),
        FunctionInfo(/* 4 */ "event", "(Lio/qt/core/QEvent;)Z"),
        FunctionInfo(/* 5 */ "eventFilter", "(Lio/qt/core/QObject;Lio/qt/core/QEvent;)Z"),
        FunctionInfo(/* 6 */ "timerEvent", "(Lio/qt/core/QTimerEvent;)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QtDataVisualization_QAbstractDataProxy, {
    });
// END: function table

    registerMetaObject(typeId, QtDataVisualization::QAbstractDataProxy::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerSizeOfShell(typeId, sizeof(QAbstractDataProxy_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QtDataVisualization::QAbstractDataProxy::DataType>("QtDataVisualization::QAbstractDataProxy::DataType", "io/qt/datavis/QAbstractDataProxy$DataType");
// END: enums and flags
}

==> qtjambi-datavisualization-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiDataVisualization/QAbstractDataProxy_shell.cpp <==
#include "QAbstractDataProxy_shell.h"
#include <QtJambi/Cast>

QtJambiShell* QAbstractDataProxy_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAbstractDataProxy_shell) ); }

jmethodID QAbstractDataProxy_shell::__shell_javaMethod(int pos) const { return QAbstractDataProxy_shell::__shell()->javaMethod(typeid(QAbstractDataProxy), pos); }

// emitting (writeShellConstructor)
// emitting (writeShellDestructor)
QAbstractDataProxy_shell::~QAbstractDataProxy_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAbstractDataProxy::~QAbstractDataProxy()", QAbstractDataProxy_shell::__shell())
    QAbstractDataProxy_shell::__shell()->destructed(typeid(QAbstractDataProxy));
}

void QAbstractDataProxy_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAbstractDataProxy_shell*>(ptr)->QAbstractDataProxy_shell::__shell()->tryDeleteShell(typeid(QAbstractDataProxy));
}

// emitting (writeQObjectFunctions)
const QMetaObject *QAbstractDataProxy_shell::metaObject() const
{
  return QAbstractDataProxy_shell::__shell()->metaObject();
}

void *QAbstractDataProxy_shell::qt_metacast(const char *_clname)
{
    bool ok = false;
    void *rv = QAbstractDataProxy_shell::__shell()->qt_metacast(_clname, &ok);
    QTJAMBI_INTERNAL_INSTANCE_METHOD_CALL("QAbstractDataProxy_shell::qt_metacast(const char *_clname)", QAbstractDataProxy_shell::__shell())
    if (!ok)
        rv = QAbstractDataProxy::qt_metacast(_clname);
    return rv;
}

int QAbstractDataProxy_shell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    QTJAMBI_INTERNAL_INSTANCE_METHOD_CALL("QAbstractDataProxy_shell::qt_metacall(QMetaObject::Call _c, int _id, void **_a)", QAbstractDataProxy_shell::__shell())
    _id = QAbstractDataProxy::qt_metacall(_c, _id, _a);
    if (_id >= 0)
        _id = QAbstractDataProxy_shell::__shell()->qt_metacall(_c, _id, _a);
    return _id;
}

// emitting Virtual overrides (virtualFunctions)
void QAbstractDataProxy_shell::childEvent(QChildEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::childEvent(event0);
        }
    }else{
        QObject::childEvent(event0);
    }
}

void QAbstractDataProxy_shell::connectNotify(const QMetaMethod& signal0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_signal0 = qtjambi_cast<jobject>(__jni_env, signal0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_signal0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::connectNotify(signal0);
        }
    }else{
        QObject::connectNotify(signal0);
    }
}

void QAbstractDataProxy_shell::customEvent(QEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(2)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::customEvent(event0);
        }
    }else{
        QObject::customEvent(event0);
    }
}

void QAbstractDataProxy_shell::disconnectNotify(const QMetaMethod& signal0)
{
    if(jmethodID method_id = __shell_javaMethod(3)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_signal0 = qtjambi_cast<jobject>(__jni_env, signal0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_signal0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::disconnectNotify(signal0);
        }
    }else{
        QObject::disconnectNotify(signal0);
    }
}

bool QAbstractDataProxy_shell::event(QEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(4)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    if(event0->type()==QEvent::DeferredDelete || event0->type()==QEvent::ChildRemoved){
                        __qt_return_value = QObject::event(event0);
                    } else {
                        QAbstractDataProxy_shell::__shell()->warnForMethod("QAbstractDataProxy::", this);
                    }
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractDataProxy::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QObject::event(event0);
        }
    }else{
        return QObject::event(event0);
    }
}

bool QAbstractDataProxy_shell::eventFilter(QObject* watched0, QEvent* event1)
{
    if(jmethodID method_id = __shell_javaMethod(5)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{400}) {
            QtJambiExceptionHandler __qj_exnhandler;
            bool  __qt_return_value = false;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_watched0 = qtjambi_cast<jobject>(__jni_env, watched0);
                    jobject __java_event1 = qtjambi_cast<jobject>(__jni_env, event1);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event1);
                    jboolean __java_return_value = __jni_env->CallBooleanMethod(__java_this, method_id, __java_watched0, __java_event1);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = static_cast<bool>(__java_return_value);
                } else {
                    if(event1->type()==QEvent::DeferredDelete || event1->type()==QEvent::ChildRemoved){
                        __qt_return_value = QObject::eventFilter(watched0, event1);
                    } else {
                        QAbstractDataProxy_shell::__shell()->warnForMethod("QAbstractDataProxy::", this);
                    }
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractDataProxy::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QObject::eventFilter(watched0, event1);
        }
    }else{
        return QObject::eventFilter(watched0, event1);
    }
}

void QAbstractDataProxy_shell::timerEvent(QTimerEvent* event0)
{
    if(jmethodID method_id = __shell_javaMethod(6)){
        QTJAMBI_JAVA_METHOD_CALL("QAbstractDataProxy::", QAbstractDataProxy_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QAbstractDataProxy_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_event0 = qtjambi_cast<jobject>(__jni_env, event0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_event0);
                    __jni_env->CallVoidMethod(__java_this, method_id, __java_event0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QAbstractDataProxy_shell::__shell()->warnForMethod("QAbstractDataProxy::", this);
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAbstractDataProxy::");
            } QTJAMBI_TRY_END
        }else{
            QObject::timerEvent(event0);
        }
    }else{
        QObject::timerEvent(event0);
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// destruct QAbstractDataProxy_shell
void __qt_destruct_QAbstractDataProxy(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAbstractDataProxy")
    reinterpret_cast<QAbstractDataProxy_shell*>(ptr)->~QAbstractDataProxy_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAbstractDataProxy::type()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_datavis_QAbstractDataProxy_type_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QAbstractDataProxy *__qt_this = QtJambiAPI::objectFromNativeId<QAbstractDataProxy>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAbstractDataProxy::type()const", __qt_this)
        QAbstractDataProxy::DataType __qt_return_value = __qt_this->type();
        __java_return_value = __qt_return_value;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAbstractDataProxy(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerQObjectTypeInfo<QAbstractDataProxy>("QAbstractDataProxy", "io/qt/datavis/QAbstractDataProxy");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "childEvent", "(Lio/qt/core/QChildEvent;)V"),
        FunctionInfo(/* 1 */ "connectNotify", "(Lio/qt/core/QMetaMethod;)V"),
        FunctionInfo(/* 2 */ "customEvent", "(Lio/qt/core/QEvent;)V"),
        FunctionInfo(/* 3 */ "disconnectNotify", "(Lio/qt/core/QMetaMethod;)V"),
        FunctionInfo(/* 4 */ "event", "(Lio/qt/core/QEvent;)Z"),
        FunctionInfo(/* 5 */ "eventFilter", "(Lio/qt/core/QObject;Lio/qt/core/QEvent;)Z"),
        FunctionInfo(/* 6 */ "timerEvent", "(Lio/qt/core/QTimerEvent;)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QAbstractDataProxy, {
    });
// END: function table

    registerMetaObject(typeId, QAbstractDataProxy::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerSizeOfShell(typeId, sizeof(QAbstractDataProxy_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QAbstractDataProxy::DataType>("QAbstractDataProxy::DataType", "io/qt/datavis/QAbstractDataProxy$DataType");
// END: enums and flags
}
